==> driza-0.5.2.tar.gz: driza-0.5.2/Driza/gestores.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
#Gestores.py

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from Driza.clasesbase import OperacionCalculo
from Driza.clasesbase import OperacionDistribucion
from Driza.clasesbase import OperacionGraficos
from qt import *



class GestorOperaciones(dict):
	"""Gestiona las operaciones que están activas en la ejecución del programa"""
	def __init__(self,dato):
		self.lista=list()
		self.__dato=dato
		self.__initintegrado()

	
	def __initintegrado(self):
		"""Esta funcion carga en el diccionario las operaciones"""
		import Driza.operaciones.descriptivo
		odescriptivo=OperacionCalculo("descriptivo",self.__dato,Driza.operaciones.descriptivo.widget,Driza.operaciones.descriptivo.funcion,Driza.operaciones.descriptivo.interfazresultado,Driza.operaciones.descriptivo.initresultado)	
		self.__setitem__("descriptivo",odescriptivo)
		import Driza.operaciones.jicuadrado
		ojicuadrado=OperacionCalculo("jicuadrado",self.__dato,Driza.operaciones.jicuadrado.widget,Driza.operaciones.jicuadrado.funcion,Driza.operaciones.jicuadrado.interfazresultado,Driza.operaciones.jicuadrado.initresultado)	
		self.__setitem__("jicuadrado",ojicuadrado)
		import Driza.operaciones.ks
		oks=OperacionCalculo("ks",self.__dato,Driza.operaciones.ks.widget,Driza.operaciones.ks.funcion,Driza.operaciones.ks.interfazresultado,Driza.operaciones.ks.initresultado)	
		self.__setitem__("ks",oks)
		import Driza.operaciones.regresion
		oregresion=OperacionCalculo("regresion",self.__dato,Driza.operaciones.regresion.widget,Driza.operaciones.regresion.funcion,Driza.operaciones.regresion.interfazresultado,Driza.operaciones.regresion.initresultado)	
		self.__setitem__("regresion",oregresion)
		import Driza.operaciones.histograma
		ohistograma=OperacionGraficos("histograma",self.__dato,Driza.operaciones.histograma.widget,Driza.operaciones.histograma.funcion,Driza.operaciones.histograma.interfazresultado,Driza.operaciones.histograma.initresultado)	
		self.__setitem__("histograma",ohistograma)
		import Driza.operaciones.dnormal
		odnormal=OperacionDistribucion("dnormal",self.__dato,Driza.operaciones.dnormal.widget,Driza.operaciones.dnormal.funcion,Driza.operaciones.dnormal.interfazresultado,Driza.operaciones.dnormal.initresultado)	
		self.__setitem__("dnormal",odnormal)
		import Driza.operaciones.ddispersion
		oddispersion=OperacionGraficos("ddispersion",self.__dato,Driza.operaciones.ddispersion.widget,Driza.operaciones.ddispersion.funcion,Driza.operaciones.ddispersion.interfazresultado,Driza.operaciones.ddispersion.initresultado)	
		self.__setitem__("ddispersion",oddispersion)


class GestorContenedorVariable:
	"""Clase que sirve a otras clases para saber que variable actua como filtro o agrupacion por ejemplo"""
	def __init__(self):
		self.variable=None
	def set(self,variable):
		self.variable=variable


class GestorFiltro(GestorContenedorVariable):
	"""Almacena la variable que actua como filtro"""
	def set(self,filtro):
		from Driza.variables import TBooleano
		assert isinstance(filtro,TBooleano)
		GestorContenedorVariable.set(self,filtro)
	

class GestorAgrupacion(GestorContenedorVariable):
	"""Almacena la variable que actua como Agrupacion"""
	def set(self,agrupacion):
		from Driza.variables import TEntero
		assert isinstance(agrupacion,TEntero)
		GestorContenedorVariable.set(self,agrupacion)

class GestorFicheros:
	"""Almacena la variable que actua como fichero.  Dispone además de funciones de carga y almacenamiento"""
	def __init__(self,portero,interfazdato):
		from Driza.interfaz import InterfazFichero
		self.fichero=None
		self.__portero=portero
		self.__if=InterfazFichero(interfazdato)


	def guardar(self,fichero=None,sobreescribir=False):
		"""Guarda la copia actual de los datos en el fichero indicado"""
		if fichero: self.fichero=fichero
		import os
		if not sobreescribir and os.path.exists(self.fichero): #El fichero existe
			from Driza.excepciones import FicheroExisteException
			raise FicheroExisteException(self.fichero)
		else:
			self.__if[self.fichero]=self.__portero.actual()

	def cargar(self,fichero=None):
		"""Carga los datos del fichero indicado"""
		if fichero: self.fichero=fichero
		if not self.fichero:
			pass #Excepcion
		self.__portero.guardarestado()
		self.__if[self.fichero]
		
		#self.config["lfichero"].insert(self.fichero)
		#TODO: Integrar eso

	def importartexto(self,fichero=None,delimitadorreg="\n",delimitadoratrib="\t",cabeceras=False):
		self.__if.importartexto(fichero,delimitadorreg,delimitadoratrib,cabeceras)
		

class GestorTemas:
	"""Gestiona los temas. Su utilidad real queda pendiente de futuros diseños"""
	def __init__(self):
		import os
		self.temaactual=None
		self.ruta=None
		posiblesrutas=["Driza/images/","/usr/lib/python2.4/site-packages/Driza/images/","~/.driza/images/"]
		for ruta in posiblesrutas:
			if os.path.exists(ruta):
				self.ruta=ruta
				break

		if not self.ruta:
			print "ERROR" #TODO: Raise excepción

	def portada(self):
		return QPixmap(self.ruta+"driza.png")

	def iconoabrir(self):
		"""Devuelve un QImage con el icono de abrir"""
		return QPixmap(self.ruta+"botonabrir.png")

	def iconoguardar(self):
		return QPixmap(self.ruta+"botonguardar.png")

	def iconoexportar(self):
		return QPixmap(self.ruta+"botonexportar.png")

==> driza-0.5.3.tar.gz: driza-0.5.3/Driza/gestores.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
#Gestores.py

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from Driza.clasesbase import OperacionCalculo
from Driza.clasesbase import OperacionDistribucion
from Driza.clasesbase import OperacionGraficos
from qt import *



class GestorOperaciones(dict):
	"""Gestiona las operaciones que están activas en la ejecución del programa"""
	def __init__(self,dato):
		self.lista=list()
		self.__dato=dato
		self.__initintegrado()

	
	def __initintegrado(self):
		"""Esta funcion carga en el diccionario las operaciones"""
		#Sacado de: http://www.diveintopython.org/functional_programming/all_together.html
		import Driza.operaciones
		ruta=Driza.operaciones.__path__[0]
		import os
		import re
		ficheros=os.listdir(ruta)
		del ficheros[ficheros.index("__init__.py")]
		test = re.compile(".*\.py$", re.IGNORECASE)
		ficheros = filter(test.search, ficheros)   
		filenameToModuleName = lambda f: os.path.splitext(f)[0]
		moduleNames = map(filenameToModuleName, ficheros)
		mifuncion=lambda f: "Driza.operaciones."+f
		moduleNames = map(mifuncion, moduleNames)
		mifuncion2=lambda f: __import__(f,None,None,["Driza.operaciones"])
		modules = map(mifuncion2, moduleNames) 
		for operacion in modules:
			try:
				tipo=operacion.tipo
				if tipo=="Calculo":
					mioperacion=OperacionCalculo(operacion.nombre,self.__dato,operacion.widget,operacion.funcion,operacion.interfazresultado,operacion.initresultado)	
				elif tipo=="Distribucion":
					mioperacion=OperacionDistribucion(operacion.nombre,self.__dato,operacion.widget,operacion.funcion,operacion.interfazresultado,operacion.initresultado)	
				elif tipo=="Graficos":
					mioperacion=OperacionGraficos(operacion.nombre,self.__dato,operacion.widget,operacion.funcion,operacion.interfazresultado,operacion.initresultado)	
				self.__setitem__(operacion.nombre,mioperacion)

			except:
				print u"Módulo erróneo"

class GestorContenedorVariable:
	"""Clase que sirve a otras clases para saber que variable actua como filtro o agrupacion por ejemplo"""
	def __init__(self):
		self.variable=None
	def set(self,variable):
		self.variable=variable


class GestorFiltro(GestorContenedorVariable):
	"""Almacena la variable que actua como filtro"""
	def set(self,filtro):
		from Driza.variables import TBooleano
		assert isinstance(filtro,TBooleano)
		GestorContenedorVariable.set(self,filtro)
	

class GestorAgrupacion(GestorContenedorVariable):
	"""Almacena la variable que actua como Agrupacion"""
	def set(self,agrupacion):
		from Driza.variables import TEntero
		assert isinstance(agrupacion,TEntero)
		GestorContenedorVariable.set(self,agrupacion)

class GestorFicheros:
	"""Almacena la variable que actua como fichero.  Dispone además de funciones de carga y almacenamiento"""
	def __init__(self,portero,interfazdato):
		from Driza.interfaz import InterfazFichero
		self.fichero=None
		self.__portero=portero
		self.__if=InterfazFichero(interfazdato)


	def guardar(self,fichero=None,sobreescribir=False):
		"""Guarda la copia actual de los datos en el fichero indicado"""
		if fichero: self.fichero=fichero
		import os
		if not sobreescribir and os.path.exists(self.fichero): #El fichero existe
			from Driza.excepciones import FicheroExisteException
			raise FicheroExisteException(self.fichero)
		else:
			self.__if[self.fichero]=self.__portero.actual()

	def cargar(self,fichero=None):
		"""Carga los datos del fichero indicado"""
		if fichero: self.fichero=fichero
		if not self.fichero:
			pass #Excepcion
		self.__portero.guardarestado()
		self.__if[self.fichero]
		
		#self.config["lfichero"].insert(self.fichero)
		#TODO: Integrar eso

	def importartexto(self,fichero=None,delimitadorreg="\n",delimitadoratrib="\t",cabeceras=False):
		self.__if.importartexto(fichero,delimitadorreg,delimitadoratrib,cabeceras)
		

class GestorTemas:
	"""Gestiona los temas. Su utilidad real queda pendiente de futuros diseños"""
	def __init__(self):
		import os
		self.temaactual=None
		self.ruta=None
		posiblesrutas=["Driza/images/","/usr/lib/python2.4/site-packages/Driza/images/","~/.driza/images/"]
		for ruta in posiblesrutas:
			if os.path.exists(ruta):
				self.ruta=ruta
				break

		if not self.ruta:
			print "ERROR" #TODO: Raise excepción

	def portada(self):
		return QPixmap(self.ruta+"driza.png")

	def iconoabrir(self):
		"""Devuelve un QImage con el icono de abrir"""
		return QPixmap(self.ruta+"botonabrir.png")

	def iconoguardar(self):
		return QPixmap(self.ruta+"botonguardar.png")

	def iconoexportar(self):
		return QPixmap(self.ruta+"botonexportar.png")
